@@ -24,6 +24,7 @@
 #include <CalendarSupport/KCalPrefs>
 #include <CalendarSupport/Utils>
 
+#include <Akonadi/AgentConfigurationDialog>
 #include <Akonadi/AgentFilterProxyModel>
 #include <Akonadi/AgentInstanceCreateJob>
 #include <Akonadi/AgentManager>
@@ -37,9 +38,9 @@
 #include <Akonadi/EntityDisplayAttribute>
 #include <Akonadi/EntityTreeModel>
 #include <Akonadi/EntityTreeView>
+#include <Akonadi/SelectCollection>
 #include <Akonadi/StandardCalendarActionManager>
 #include <PimCommonAkonadi/MailUtil>
-#include <PimCommonAkonadi/ManageServerSideSubscriptionJob>
 
 #include <KActionCollection>
 #include <KCheckableProxyModel>
@@ -80,7 +81,7 @@ class NewCalendarChecker : public QObject
 {
     Q_OBJECT
 public:
-    NewCalendarChecker(QAbstractItemModel *model)
+    explicit NewCalendarChecker(QAbstractItemModel *model)
         : QObject(model)
         , mCheckableProxy(model)
     {
@@ -111,7 +112,7 @@ private Q_SLOTS:
         }
     }
 
-private:
+private: // NOLINT(readability-redundant-access-specifiers)
     QAbstractItemModel *const mCheckableProxy;
 };
 
@@ -143,7 +144,7 @@ public:
         // but that unfortunately doesn't seem to work
     }
 
-public Q_SLOTS:
+public Q_SLOTS: // NOLINT(readability-redundant-access-specifiers)
     void saveState()
     {
         saveTreeState();
@@ -184,7 +185,7 @@ private Q_SLOTS:
         }
     }
 
-private:
+private: // NOLINT(readability-redundant-access-specifiers)
     void saveTreeState()
     {
         Akonadi::ETMViewStateSaver treeStateSaver;
@@ -204,12 +205,14 @@ private:
         if (!findEtm(mTreeView->model())) {
             return;
         }
-        if (treeStateRestorer) { // We don't need more than one to be running at the same time
+        // NOLINT(readability-delete-null-pointer)
+        if (treeStateRestorer) { // NOLINT(readability-delete-null-pointer)
+            // We don't need more than one to be running at the same time
             delete treeStateRestorer;
         }
         qCDebug(KORGANIZER_LOG) << "Restore tree state";
         treeStateRestorer = new Akonadi::ETMViewStateSaver(); // not a leak
-        KConfigGroup group(KSharedConfig::openConfig(), mTreeStateConfig);
+        KConfigGroup const group(KSharedConfig::openConfig(), mTreeStateConfig);
         treeStateRestorer->setView(mTreeView);
         treeStateRestorer->setSelectionModel(nullptr); // we only restore expand state
         treeStateRestorer->restoreState(group);
@@ -251,7 +254,6 @@ class ColorProxyModel : public QSortFilterProxyModel
 public:
     explicit ColorProxyModel(QObject *parent = nullptr)
         : QSortFilterProxyModel(parent)
-        , mInitDefaultCalendar(false)
     {
     }
 
@@ -286,7 +288,7 @@ public:
             const Akonadi::Collection::Id colId = collection.id();
             const Akonadi::AgentInstance instance = Akonadi::AgentManager::self()->instance(collection.resource());
             if (!instance.isOnline() && !collection.isVirtual()) {
-                return i18nc("@item this is the default calendar", "%1 (Offline)", collection.displayName());
+                return i18nc("@item this calendar is offline", "%1 (Offline)", collection.displayName());
             }
             if (colId == CalendarSupport::KCalPrefs::instance()->defaultCalendarId()) {
                 return i18nc("@item this is the default calendar", "%1 (Default)", collection.displayName());
@@ -302,7 +304,7 @@ public:
     }
 
 private:
-    mutable bool mInitDefaultCalendar;
+    mutable bool mInitDefaultCalendar = false;
 };
 
 class CollectionFilter : public QSortFilterProxyModel
@@ -347,31 +349,6 @@ public:
         : QSortFilterProxyModel(parent)
     {
     }
-
-protected:
-    [[nodiscard]] bool checkChildren(const QModelIndex &index, int role, const QVariant &value) const
-    {
-        const QModelIndex sourceIndex = mapToSource(index);
-        for (int i = 0; i < sourceModel()->rowCount(sourceIndex); ++i) {
-            const QModelIndex child = sourceModel()->index(i, 0, sourceIndex);
-            if (child.data(role) != value) {
-                return false;
-            }
-        }
-        return true;
-    }
-
-    void setChildren(const QModelIndex &sourceIndex, const QVariant &value, int role) const
-    {
-        if (!sourceIndex.isValid()) {
-            return;
-        }
-        for (int i = 0; i < sourceModel()->rowCount(sourceIndex); ++i) {
-            const QModelIndex child = sourceModel()->index(i, 0, sourceIndex);
-            sourceModel()->setData(child, value, role);
-            setChildren(child, value, role);
-        }
-    }
 };
 }
 
@@ -405,13 +382,10 @@ AkonadiCollectionView::AkonadiCollectionView(CalendarView *view, bool hasContext
     topLayout->setContentsMargins({});
 
     auto searchCol = new QLineEdit(this);
-    searchCol->setToolTip(i18nc("@info:tooltip", "Set search keyword"));
-    searchCol->setWhatsThis(i18nc("@info:whatsthis", "Lets you search for a keyword in your calendars"));
+    searchCol->setToolTip(i18nc("@info:tooltip", "Calendar search"));
+    searchCol->setWhatsThis(i18nc("@info:whatsthis", "Start typing to search for a calendar within the collection."));
     searchCol->setClearButtonEnabled(true);
-    searchCol->setPlaceholderText(
-        i18nc("@info/plain Displayed grayed-out inside the "
-              "textbox, verb to search",
-              "Search…"));
+    searchCol->setPlaceholderText(i18nc("@info/plain Displayed grayed-out inside the textbox, calendar to search", "Search for calendar…"));
     topLayout->addWidget(searchCol);
 
     auto colorProxy = new ColorProxyModel(this);
@@ -472,7 +446,7 @@ AkonadiCollectionView::AkonadiCollectionView(CalendarView *view, bool hasContext
                         << Akonadi::StandardActionManager::SynchronizeResources << Akonadi::StandardActionManager::SynchronizeCollectionTree
                         << Akonadi::StandardActionManager::CopyCollectionToMenu << Akonadi::StandardActionManager::MoveCollectionToMenu;
 
-        for (Akonadi::StandardActionManager::Type standardAction : std::as_const(standardActions)) {
+        for (Akonadi::StandardActionManager::Type const standardAction : std::as_const(standardActions)) {
             mActionManager->createAction(standardAction);
         }
 
@@ -481,7 +455,7 @@ AkonadiCollectionView::AkonadiCollectionView(CalendarView *view, bool hasContext
                         << Akonadi::StandardCalendarActionManager::CreateSubTodo << Akonadi::StandardCalendarActionManager::CreateJournal
                         << Akonadi::StandardCalendarActionManager::EditIncidence;
 
-        for (Akonadi::StandardCalendarActionManager::Type calendarAction : std::as_const(calendarActions)) {
+        for (Akonadi::StandardCalendarActionManager::Type const calendarAction : std::as_const(calendarActions)) {
             mActionManager->createAction(calendarAction);
         }
 
@@ -519,10 +493,6 @@ AkonadiCollectionView::AkonadiCollectionView(CalendarView *view, bool hasContext
         mDefaultCalendar->setEnabled(false);
         xmlclient->actionCollection()->addAction(QStringLiteral("set_standard_calendar"), mDefaultCalendar);
         connect(mDefaultCalendar, &QAction::triggered, this, &AkonadiCollectionView::setDefaultCalendar);
-
-        mServerSideSubscription = new QAction(QIcon::fromTheme(QStringLiteral("folder-bookmarks")), i18nc("@action:inmenu", "Serverside Subscription…"), this);
-        xmlclient->actionCollection()->addAction(QStringLiteral("serverside_subscription"), mServerSideSubscription);
-        connect(mServerSideSubscription, &QAction::triggered, this, &AkonadiCollectionView::slotServerSideSubscription);
     }
 }
 
@@ -533,20 +503,6 @@ AkonadiCollectionView::~AkonadiCollectionView()
     mNewNodeExpander->saveState();
 }
 
-void AkonadiCollectionView::slotServerSideSubscription()
-{
-    const QModelIndex index = mCollectionView->selectionModel()->currentIndex(); // selectedRows()
-    Q_ASSERT(index.isValid());
-    const Akonadi::Collection collection = Akonadi::CollectionUtils::fromIndex(index);
-    if (!collection.isValid()) {
-        return;
-    }
-    auto job = new PimCommon::ManageServerSideSubscriptionJob(this);
-    job->setCurrentCollection(collection);
-    job->setParentWidget(this);
-    job->start();
-}
-
 Akonadi::Collection AkonadiCollectionView::currentCalendar() const
 {
     const QModelIndex index = mCollectionView->selectionModel()->currentIndex(); // selectedRows()
@@ -555,22 +511,50 @@ Akonadi::Collection AkonadiCollectionView::currentCalendar() const
     return collection;
 }
 
+QString AkonadiCollectionView::defaultCalendarDisplayName() const
+{
+    QString displayName;
+    const Akonadi::Collection::Id calendarId = CalendarSupport::KCalPrefs::instance()->defaultCalendarId();
+    if (calendarId != -1) {
+        const Akonadi::Collection defaultCollection(calendarId);
+        if (defaultCollection.isValid()) {
+            const QModelIndex defaultIdx = Akonadi::EntityTreeModel::modelIndexForCollection(entityTreeModel(), defaultCollection);
+            if (defaultIdx.isValid()) {
+                displayName = defaultIdx.model()->data(defaultIdx, Qt::DisplayRole).toString();
+            }
+        }
+    }
+    return displayName;
+}
+
 void AkonadiCollectionView::setDefaultCalendar()
 {
-    QModelIndex index = mCollectionView->selectionModel()->currentIndex(); // selectedRows()
+    QModelIndex const index = mCollectionView->selectionModel()->currentIndex(); // selectedRows()
     Q_ASSERT(index.isValid());
     const Akonadi::Collection collection = Akonadi::CollectionUtils::fromIndex(index);
+    const QString displayName = index.model()->data(index, Qt::DisplayRole).toString();
 
     // Ask if they really want to do this
-    const Akonadi::Collection curCol(CalendarSupport::KCalPrefs::instance()->defaultCalendarId());
-    if (curCol.isValid()
-        && KMessageBox::warningContinueCancel(this,
-                                              i18nc("@info", "Do you really want replace your current default calendar with \"%1\"?", collection.displayName()),
-                                              i18nc("@title:window", "Replace Default Calendar?"))
-            != KMessageBox::Continue) {
+    const QString defaultDisplayName = defaultCalendarDisplayName();
+    QString continueCancelMsg;
+    if (!defaultDisplayName.isEmpty()) {
+        continueCancelMsg = xi18nc("@info",
+                                   "Do you really want to set <filename>%1</filename> as your default calendar folder?"
+                                   "<para>This will replace <filename>%2</filename> as the default calendar folder.</para>",
+                                   displayName,
+                                   defaultDisplayName);
+    } else {
+        continueCancelMsg = xi18nc("@info", "Do you really want to set <filename>%1</filename> as your default calendar folder?", displayName);
+    }
+
+    const Akonadi::Collection defaultCol(CalendarSupport::KCalPrefs::instance()->defaultCalendarId());
+    if (defaultCol.isValid()
+        && KMessageBox::warningContinueCancel(this, continueCancelMsg, i18nc("@title:window", "Replace Default Calendar?")) != KMessageBox::Continue) {
         return;
     }
 
+    mCalendarView->showMessage(xi18nc("@info", "<filename>%1</filename> is now your default event calendar", displayName), KMessageWidget::Information);
+
     CalendarSupport::KCalPrefs::instance()->setDefaultCalendarId(collection.id());
     CalendarSupport::KCalPrefs::instance()->usrSave();
     updateMenu();
@@ -581,7 +565,7 @@ void AkonadiCollectionView::setDefaultCalendar()
 
 void AkonadiCollectionView::assignColor()
 {
-    QModelIndex index = mCollectionView->selectionModel()->currentIndex(); // selectedRows()
+    QModelIndex const index = mCollectionView->selectionModel()->currentIndex(); // selectedRows()
     Q_ASSERT(index.isValid());
     const Akonadi::Collection collection = Akonadi::CollectionUtils::fromIndex(index);
     Q_ASSERT(collection.isValid());
@@ -603,12 +587,11 @@ void AkonadiCollectionView::setCollectionSelectionProxyModel(KCheckableProxyMode
         return;
     }
 
-    m->selectionModel()->disconnect(this);
-
     mSelectionProxyModel = m;
     if (!mSelectionProxyModel) {
         return;
     }
+    m->selectionModel()->disconnect(this);
 
     new NewCalendarChecker(m);
     mBaseModel->setSourceModel(mSelectionProxyModel);
@@ -616,16 +599,12 @@ void AkonadiCollectionView::setCollectionSelectionProxyModel(KCheckableProxyMode
     connect(m->selectionModel(), &QItemSelectionModel::selectionChanged, this, &AkonadiCollectionView::selectionChanged);
 }
 
-KCheckableProxyModel *AkonadiCollectionView::collectionSelectionProxyModel() const
-{
-    return mSelectionProxyModel;
-}
-
 void AkonadiCollectionView::selectionChanged(const QItemSelection &selected, const QItemSelection &deselected)
 {
     bool changed = false;
 
-    for (const auto &index : selected.indexes()) {
+    const auto selectedIndexes = selected.indexes();
+    for (const auto &index : selectedIndexes) {
         if (!index.isValid()) {
             continue;
         }
@@ -637,7 +616,8 @@ void AkonadiCollectionView::selectionChanged(const QItemSelection &selected, con
         }
     }
 
-    for (const auto &index : deselected.indexes()) {
+    const auto deselectedIndexes = deselected.indexes();
+    for (const auto &index : deselectedIndexes) {
         if (!index.isValid()) {
             continue;
         }
@@ -664,6 +644,36 @@ void AkonadiCollectionView::updateView()
     Q_EMIT resourcesChanged(mSelectionProxyModel ? mSelectionProxyModel->selectionModel()->hasSelection() : false);
 }
 
+bool AkonadiCollectionView::isCalendarFolder(const Akonadi::Collection &collection) const
+{
+    return !collection.contentMimeTypes().contains(QLatin1StringView("inode/directory"));
+}
+
+bool AkonadiCollectionView::isCollectionDefaultable(const Akonadi::Collection &collection, const QString &mimeType) const
+{
+    bool canDefault = false;
+    if (collection.isValid() && !collection.contentMimeTypes().isEmpty() && !collectionIsDefaultCalendar(collection)) {
+        if (collection.remoteId() != QLatin1StringView("akonadi_birthdays_resource")) {
+            const bool isWriteable = collection.rights() & Akonadi::Collection::CanCreateItem;
+            canDefault = isWriteable && !collection.isVirtual() && collection.contentMimeTypes().contains(mimeType);
+        }
+    }
+    return canDefault;
+}
+
+Akonadi::Collection::List AkonadiCollectionView::defaultableCollections(const QString &mimeType) const
+{
+    Akonadi::Collection::List collections;
+    for (int i = 0; i < entityTreeModel()->rowCount(); ++i) {
+        const QModelIndex index = entityTreeModel()->index(i, 0);
+        const Akonadi::Collection collection = index.data(Akonadi::EntityTreeModel::CollectionRole).value<Akonadi::Collection>();
+        if (isCollectionDefaultable(collection, mimeType)) {
+            collections << collection;
+        }
+    }
+    return collections;
+}
+
 void AkonadiCollectionView::updateMenu()
 {
     if (!mHasContextMenu) {
@@ -672,7 +682,7 @@ void AkonadiCollectionView::updateMenu()
     bool enableAction = mCollectionView->selectionModel()->hasSelection();
     enableAction = enableAction && (KOPrefs::instance()->agendaViewColors() != KOPrefs::CategoryOnly);
     mAssignColor->setEnabled(enableAction);
-    QModelIndex index = mCollectionView->selectionModel()->currentIndex(); // selectedRows()
+    QModelIndex const index = mCollectionView->selectionModel()->currentIndex(); // selectedRows()
 
     bool disableStuff = true;
 
@@ -689,10 +699,6 @@ void AkonadiCollectionView::updateMenu()
                                          && !collection.isVirtual() && collection.contentMimeTypes().contains(KCalendarCore::Event::eventMimeType()));
             disableStuff = false;
         }
-        bool isOnline;
-        mServerSideSubscription->setEnabled(PimCommon::MailUtil::isImapFolder(collection, isOnline));
-    } else {
-        mServerSideSubscription->setEnabled(false);
     }
     if (disableStuff) {
         mDefaultCalendar->setEnabled(false);
@@ -702,7 +708,7 @@ void AkonadiCollectionView::updateMenu()
 
 void AkonadiCollectionView::newCalendar()
 {
-    QPointer<Akonadi::AgentTypeDialog> dlg = new Akonadi::AgentTypeDialog(this);
+    QPointer<Akonadi::AgentTypeDialog> const dlg = new Akonadi::AgentTypeDialog(this);
     dlg->setWindowTitle(i18nc("@title:window", "Add Calendar"));
     dlg->agentFilterProxyModel()->addMimeTypeFilter(QStringLiteral("text/calendar"));
     dlg->agentFilterProxyModel()->addCapabilityFilter(QStringLiteral("Resource")); // show only resources, no agents
@@ -711,7 +717,6 @@ void AkonadiCollectionView::newCalendar()
         const Akonadi::AgentType agentType = dlg->agentType();
         if (agentType.isValid()) {
             auto job = new Akonadi::AgentInstanceCreateJob(agentType, this);
-            job->configure(this);
             connect(job, &Akonadi::AgentInstanceCreateJob::result, this, &AkonadiCollectionView::newCalendarDone);
             job->start();
         }
@@ -723,20 +728,42 @@ void AkonadiCollectionView::newCalendarDone(KJob *job)
 {
     auto createjob = static_cast<Akonadi::AgentInstanceCreateJob *>(job);
     if (createjob->error()) {
-        // TODO(AKONADI_PORT)
-        // this should show an error dialog and should be merged
-        // with the identical code in ActionManager
-        qCWarning(KORGANIZER_LOG) << "Create calendar failed:" << createjob->errorString();
-        mNotSendAddRemoveSignal = false;
+        mCalendarView->showMessage(xi18nc("@info", "Add new calendar failed: <message>%1</message>", createjob->errorString()), KMessageWidget::Information);
+        mNotSendAddRemoveSignal = true; // no changes on failed add calendar
         return;
     }
+
+    auto configureDialog = new Akonadi::AgentConfigurationDialog(createjob->instance(), this);
+    configureDialog->setAttribute(Qt::WA_DeleteOnClose);
+    connect(configureDialog, &QDialog::rejected, this, [instance = createjob->instance()] {
+        Akonadi::AgentManager::self()->removeInstance(instance);
+    });
+    configureDialog->show();
+
     mNotSendAddRemoveSignal = false;
-    // TODO
+}
+
+bool AkonadiCollectionView::collectionContainsDefaultCalendar(const Akonadi::Collection &collection) const
+{
+    if (collectionIsDefaultCalendar(collection)) {
+        return true;
+    }
+
+    const Akonadi::Collection defaultCollection(CalendarSupport::KCalPrefs::instance()->defaultCalendarId());
+    if (!defaultCollection.isValid()) {
+        return false;
+    }
+
+    const QModelIndex defaultIdx = Akonadi::EntityTreeModel::modelIndexForCollection(entityTreeModel(), defaultCollection);
+    const QModelIndex parentDefaultIdx = entityTreeModel()->parent(defaultIdx);
+    const QModelIndex idx = Akonadi::EntityTreeModel::modelIndexForCollection(entityTreeModel(), collection);
+
+    return parentDefaultIdx == idx;
 }
 
 void AkonadiCollectionView::deleteCalendar()
 {
-    QModelIndex index = mCollectionView->selectionModel()->currentIndex(); // selectedRows()
+    QModelIndex const index = mCollectionView->selectionModel()->currentIndex(); // selectedRows()
     Q_ASSERT(index.isValid());
     const Akonadi::Collection collection = Akonadi::CollectionUtils::fromIndex(index);
     Q_ASSERT(collection.isValid());
@@ -744,23 +771,78 @@ void AkonadiCollectionView::deleteCalendar()
     const QString displayname = index.model()->data(index, Qt::DisplayRole).toString();
     Q_ASSERT(!displayname.isEmpty());
 
-    bool isTopLevel = collection.parentCollection() == Akonadi::Collection::root();
+    mWasDefaultCalendar = false;
+    bool const isTopLevel = collection.parentCollection() == Akonadi::Collection::root();
+    if (isTopLevel) {
+        if (collectionContainsDefaultCalendar(collection)) {
+            mWasDefaultCalendar = true;
+        }
+    } else {
+        mWasDefaultCalendar = KOHelper::isStandardCalendar(collection.id());
+    }
 
     QString yesNoMessage;
     if (isTopLevel) {
-        yesNoMessage = xi18nc("@info",
-                              "Do you really want to delete the <filename>%1</filename> calendar?"
-                              "<para><note>The calendar data will not be deleted, nor will the calendar "
-                              "be removed from its remote resource.</note></para>"
-                              "The <filename>%1</filename> calendar can be added again at any time.",
-                              displayname);
+        if (!mWasDefaultCalendar) {
+            yesNoMessage = xi18nc("@info",
+                                  "Do you really want to delete the <filename>%1</filename> calendar?"
+                                  "<para><note>The calendar data will not be deleted, nor will the calendar "
+                                  "be removed from its remote resource. The <filename>%1</filename> calendar "
+                                  "can be added again at any time.</note></para>",
+                                  displayname);
+        } else {
+            if (!collectionIsDefaultCalendar(collection)) {
+                const QString defaultDisplayName = defaultCalendarDisplayName();
+                if (!defaultDisplayName.isEmpty()) {
+                    yesNoMessage = xi18nc("@info",
+                                          "Do you really want to delete the <filename>%1</filename> calendar?"
+                                          "<para><note>The calendar data will not be deleted, nor will the calendar "
+                                          "be removed from its remote resource. The <filename>%1</filename> calendar "
+                                          "can be added again at any time.</note></para>"
+                                          "<para><warning>This calendar contains your default calendar folder "
+                                          "<filename>%2</filename>. If you delete it you may be prompted "
+                                          "to select a new default calendar folder.</warning></para>",
+                                          displayname,
+                                          defaultDisplayName);
+                } else {
+                    yesNoMessage = xi18nc("@info",
+                                          "Do you really want to delete the <filename>%1</filename> calendar?"
+                                          "<para><note>The calendar data will not be deleted, nor will the calendar "
+                                          "be removed from its remote resource. The <filename>%1</filename> calendar "
+                                          "can be added again at any time.</note></para><para><warning>This calendar "
+                                          "contains your default calendar folder. If you delete it you may be prompted "
+                                          "to select a new default calendar folder.</warning></para>",
+                                          displayname);
+                }
+            } else {
+                yesNoMessage = xi18nc("@info",
+                                      "Do you really want to delete the <filename>%1</filename> calendar?"
+                                      "<para><note>The calendar data will not be deleted, nor will the calendar "
+                                      "be removed from its remote resource. The <filename>%1</filename> calendar "
+                                      "can be added again at any time.</note></para>"
+                                      "<para><warning>This is your default calendar. If you delete it you may be "
+                                      "prompted to select a new default calendar.</warning></para>",
+                                      displayname);
+            }
+        }
     } else {
-        yesNoMessage = xi18nc("@info",
-                              "Do you really want to delete the <filename>%1</filename> calendar?"
-                              "<para><warning>This cannot be undone.  "
-                              "Please consider carefully before pressing the %2 button.</warning></para>",
-                              displayname,
-                              KStandardGuiItem::standardItem(KStandardGuiItem::Delete));
+        if (!mWasDefaultCalendar) {
+            yesNoMessage = xi18nc("@info",
+                                  "Do you really want to delete the <filename>%1</filename> folder?"
+                                  "<para><warning>This cannot be undone. "
+                                  "Please consider carefully before pressing the %2 button.</warning></para>",
+                                  displayname,
+                                  KStandardGuiItem::standardItem(KStandardGuiItem::Delete));
+        } else {
+            yesNoMessage = xi18nc("@info",
+                                  "Do you really want to delete the <filename>%1</filename> folder?"
+                                  "<para><warning>This cannot be undone. "
+                                  "Please consider carefully before pressing the %2 button.</warning></para>"
+                                  "<para><warning>This is your default calendar folder. If you delete it you may be "
+                                  "prompted to select a new default calendar.</warning></para>",
+                                  displayname,
+                                  KStandardGuiItem::standardItem(KStandardGuiItem::Delete));
+        }
     }
     if (KMessageBox::warningContinueCancel(this,
                                            yesNoMessage,
@@ -771,7 +853,6 @@ void AkonadiCollectionView::deleteCalendar()
                                            KMessageBox::Dangerous)
         == KMessageBox::Continue) {
         mNotSendAddRemoveSignal = true;
-        mWasDefaultCalendar = KOHelper::isStandardCalendar(collection.id());
 
         if (!isTopLevel) {
             // deletes contents
@@ -782,24 +863,101 @@ void AkonadiCollectionView::deleteCalendar()
             const Akonadi::AgentInstance instance = Akonadi::AgentManager::self()->instance(collection.resource());
             if (instance.isValid()) {
                 Akonadi::AgentManager::self()->removeInstance(instance);
+                resetDefaultEventCalendar();
+                mNotSendAddRemoveSignal = false;
+            } else {
+                // In the case of an invalid Agent instance the only thing we can do is remove the collection itself
+                if (collection.isValid()) {
+                    if (KMessageBox::warningContinueCancel(this,
+                                                           xi18nc("@info",
+                                                                  "The calendar you are attempting to remove is corrupted in some way. "
+                                                                  "If you continue the calendar data will be removed. "
+                                                                  "<para><warning>This cannot be undone. "
+                                                                  "Please consider carefully before pressing the %1 button.</warning></para>",
+                                                                  KStandardGuiItem::standardItem(KStandardGuiItem::Delete)),
+                                                           i18nc("@title:window", "Delete Calendar"),
+                                                           KStandardGuiItem::del(),
+                                                           KStandardGuiItem::cancel(),
+                                                           QString(),
+                                                           KMessageBox::Dangerous)
+                        == KMessageBox::Continue) {
+                        auto job = new Akonadi::CollectionDeleteJob(collection, this);
+                        connect(job, &Akonadi::AgentInstanceCreateJob::result, this, &AkonadiCollectionView::deleteCalendarDone);
+                    }
+                } else {
+                    mCalendarView->showMessage(xi18nc("@info", "Delete calendar failed: <message>Invalid Akonadi agent instance</message>"),
+                                               KMessageWidget::Information);
+                }
             }
         }
     }
 }
 
+bool AkonadiCollectionView::collectionIsDefaultCalendar(const Akonadi::Collection &collection) const
+{
+    const Akonadi::Collection defaultCollection(CalendarSupport::KCalPrefs::instance()->defaultCalendarId());
+    if (defaultCollection.isValid() && (collection == defaultCollection)) {
+        return true;
+    }
+    return false;
+}
+
+void AkonadiCollectionView::requestDefaultCalendar(const QString &mimeType)
+{
+    Akonadi::Collection::Id defaultCollectionId = -1;
+    Akonadi::Collection defaultCollection(defaultCollectionId); // invalid
+    const Akonadi::Collection::List possibleDefaultCalendars = defaultableCollections(mimeType);
+    const int possibleDefaultCalendarsRemaining = possibleDefaultCalendars.count();
+    if ((possibleDefaultCalendarsRemaining > 1) || ((possibleDefaultCalendarsRemaining == 1) && !isCalendarFolder(possibleDefaultCalendars.first()))) {
+        int dialogCode;
+        const QStringList mimeTypes = QStringList() << KCalendarCore::Event::eventMimeType();
+        const Akonadi::Collection collection = Akonadi::CalendarUtils::selectCollection(this, dialogCode /*by-ref*/, mimeTypes);
+        if (collection.isValid()) {
+            defaultCollection = collection;
+        }
+    } else if (possibleDefaultCalendarsRemaining == 1) {
+        // Automatically set the default calendar as there is only 1 possibility.
+        const Akonadi::Collection &collection = possibleDefaultCalendars.first();
+        if (collection.isValid()) {
+            defaultCollection = collection;
+        }
+    }
+    if (defaultCollection.isValid()) {
+        mCalendarView->showMessage(xi18nc("@info", "<filename>%1</filename> is now your default event calendar", defaultCollection.displayName()),
+                                   KMessageWidget::Information);
+        defaultCollectionId = defaultCollection.id();
+    } else {
+        if (possibleDefaultCalendarsRemaining) {
+            mCalendarView->showMessage(i18nc("@info", "Consider setting a default calendar for new events"), KMessageWidget::Information);
+        } else {
+            mCalendarView->showMessage(i18nc("@info", "Consider adding a write-enabled events calendar"), KMessageWidget::Information);
+        }
+    }
+
+    CalendarSupport::KCalPrefs::instance()->setDefaultCalendarId(defaultCollectionId);
+    CalendarSupport::KCalPrefs::instance()->usrSave();
+}
+
+void AkonadiCollectionView::resetDefaultEventCalendar()
+{
+    // Nothing to reset. We didn't remove the default calendar
+    if (!mWasDefaultCalendar) {
+        return;
+    }
+    // TODO: for now only event calendars are considered. implement resetDefaultTodoCalendar()
+    requestDefaultCalendar(KCalendarCore::Event::eventMimeType());
+}
+
 void AkonadiCollectionView::deleteCalendarDone(KJob *job)
 {
     auto deletejob = static_cast<Akonadi::CollectionDeleteJob *>(job);
     if (deletejob->error()) {
-        qCWarning(KORGANIZER_LOG) << "Delete calendar failed:" << deletejob->errorString();
-        mNotSendAddRemoveSignal = false;
+        mCalendarView->showMessage(xi18nc("@info", "Delete calendar failed: <message>%1</message>", deletejob->errorString()), KMessageWidget::Information);
+        mNotSendAddRemoveSignal = true; // no changes on failed delete calendar
         return;
     }
-    if (mWasDefaultCalendar) {
-        CalendarSupport::KCalPrefs::instance()->setDefaultCalendarId(Akonadi::Collection().id());
-    }
-    mNotSendAddRemoveSignal = false;
-    // TODO
+    Q_EMIT resourcesAddedRemoved();
+    resetDefaultEventCalendar();
 }
 
 void AkonadiCollectionView::rowsInserted(const QModelIndex &, int, int)
@@ -855,15 +1013,15 @@ bool AkonadiCollectionView::isChecked(const Akonadi::Collection &collection) con
         return false;
     }
     const QModelIndexList indexes = selectionModel->selectedIndexes();
-    for (const QModelIndex &index : indexes) {
+    return (std::ranges::any_of(indexes, [collection](const QModelIndex &index) {
         if (index.isValid()) {
             const auto c = index.data(Akonadi::EntityTreeModel::CollectionRole).value<Akonadi::Collection>();
             if (c.id() == collection.id()) {
                 return true;
             }
         }
-    }
-    return false;
+        return false;
+    }));
 }
 
 Akonadi::EntityTreeModel *AkonadiCollectionView::entityTreeModel() const
