@@ -39,7 +39,7 @@ KOEventViewerDialog::KOEventViewerDialog(Akonadi::ETMCalendar *calendar, QWidget
     setModal(false);
     KGuiItem::assign(mUser1Button, KGuiItem(i18nc("@action:button", "Edit…"), QIcon::fromTheme(QStringLiteral("document-edit"))));
     KGuiItem::assign(user2Button, KGuiItem(i18nc("@action:button", "Show in Context")));
-    mEventViewer = new CalendarSupport::IncidenceViewer(calendar, this);
+    mEventViewer = new CalendarSupport::IncidenceViewer(calendar->entityTreeModel(), this);
     mainLayout->addWidget(mEventViewer);
     mainLayout->addWidget(buttonBox);
 
@@ -71,11 +71,6 @@ void KOEventViewerDialog::setIncidence(const Akonadi::Item &incidence, const QDa
     mEventViewer->setIncidence(incidence, date);
 }
 
-void KOEventViewerDialog::addText(const QString &text)
-{
-    mEventViewer->setHeaderText(text);
-}
-
 void KOEventViewerDialog::editIncidence()
 {
     const Akonadi::Item item = mEventViewer->item();
@@ -83,14 +78,13 @@ void KOEventViewerDialog::editIncidence()
     if (CalendarSupport::hasIncidence(item)) {
         // make sure korganizer is running or the part is shown
         const QString desktopFile = QStandardPaths::locate(QStandardPaths::ApplicationsLocation, QStringLiteral("org.kde.korganizer.desktop"));
-        QString error;
         if (!QDBusConnection::sessionBus().interface()->startService(desktopFile).isValid()) {
             OrgKdeKorganizerKorganizerInterface korganizerIface(QStringLiteral("org.kde.korganizer"),
                                                                 QStringLiteral("/Korganizer"),
                                                                 QDBusConnection::sessionBus());
             korganizerIface.editIncidence(QString::number(item.id()));
         } else {
-            qCWarning(KORGANIZER_LOG) << "Failure starting korganizer:" << error;
+            qCWarning(KORGANIZER_LOG) << "Failure starting korganizer";
         }
     }
 }
@@ -102,14 +96,13 @@ void KOEventViewerDialog::showIncidenceContext()
     if (CalendarSupport::hasIncidence(item)) {
         // make sure korganizer is running or the part is shown
         const QString desktopFile = QStandardPaths::locate(QStandardPaths::ApplicationsLocation, QStringLiteral("org.kde.korganizer.desktop"));
-        QString error;
         if (!QDBusConnection::sessionBus().interface()->startService(desktopFile).isValid()) {
             OrgKdeKorganizerKorganizerInterface korganizerIface(QStringLiteral("org.kde.korganizer"),
                                                                 QStringLiteral("/Korganizer"),
                                                                 QDBusConnection::sessionBus());
             korganizerIface.showIncidenceContext(QString::number(item.id()));
         } else {
-            qCWarning(KORGANIZER_LOG) << "Failure starting korganizer:" << error;
+            qCWarning(KORGANIZER_LOG) << "Failure starting korganizer";
         }
     }
 }
