@@ -18,11 +18,12 @@
 #include "impl/korganizerifaceimpl.h"
 #include "kocore.h"
 #include "plugininterface/korganizerplugininterface.h"
+#include "prefs/koprefs.h"
 
 #include <Libkdepim/ProgressStatusBarWidget>
 #include <Libkdepim/StatusbarProgressWidget>
 
-// #include "korganizer_debug.h"
+#include "whatsnew/whatsnewtranslations.h"
 #include <KAboutData>
 #include <KActionCollection>
 #include <KSharedConfig>
@@ -31,12 +32,12 @@
 #include <KToolBar>
 #include <PimCommon/NeedUpdateVersionUtils>
 #include <PimCommon/NeedUpdateVersionWidget>
+#include <PimCommon/WhatsNewMessageWidget>
 #include <QLabel>
 #include <QStatusBar>
 #include <QVBoxLayout>
 #if HAVE_ACTIVITY_SUPPORT
 #include "activities/activitiesmanager.h"
-#include "prefs/koprefs.h"
 #endif
 #if KORGANIZER_WITH_KUSERFEEDBACK
 #include "userfeedback/userfeedbackmanager.h"
@@ -46,9 +47,7 @@
 #endif
 
 KOrganizer::KOrganizer()
-    : KParts::MainWindow()
-    , KOrg::MainWindow()
-    , mCalendarView(new CalendarView(this))
+    : mCalendarView(new CalendarView(this))
 {
     KOCore::self()->addXMLGUIClient(this, this);
     //  setMinimumSize(600,400);  // make sure we don't get resized too small...
@@ -65,6 +64,21 @@ KOrganizer::KOrganizer()
             needUpdateVersionWidget->setObsoleteVersion(status);
         }
     }
+
+    const WhatsNewTranslations translations;
+    const QString newFeaturesMD5 = translations.newFeaturesMD5();
+    if (!newFeaturesMD5.isEmpty()) {
+        const bool hasNewFeature = (KOPrefs::instance()->previousNewFeaturesMD5() != newFeaturesMD5);
+        if (hasNewFeature) {
+            auto whatsNewMessageWidget = new PimCommon::WhatsNewMessageWidget(this, i18n("KOrganizer"));
+            whatsNewMessageWidget->setWhatsNewInfos(translations.createWhatsNewInfo());
+            whatsNewMessageWidget->setObjectName(QStringLiteral("whatsNewMessageWidget"));
+            mainWidgetLayout->addWidget(whatsNewMessageWidget);
+            KOPrefs::instance()->setPreviousNewFeaturesMD5(newFeaturesMD5);
+            whatsNewMessageWidget->animatedShow();
+        }
+    }
+
     mainWidgetLayout->addWidget(mCalendarView);
 
     mCalendarView->setObjectName(QLatin1StringView("KOrganizer::CalendarView"));
@@ -119,48 +133,6 @@ void KOrganizer::init(bool document)
     setTitle();
 }
 
-#if 0
-void KOrganizer::initializePluginActions()
-{
-#if 0
-    if (mXmlGuiClient->factory()) {
-        QHashIterator<PimCommon::ActionType::Type, QList<QAction *> > localActionsType(
-            mPluginInterface->actionsType());
-        while (localActionsType.hasNext()) {
-            localActionsType.next();
-            QList<QAction *> lst = localActionsType.value();
-            if (!lst.isEmpty()) {
-                const QString actionlistname = QStringLiteral("korganizer")
-                                               + PimCommon::PluginInterface::actionXmlExtension(
-                    localActionsType.key());
-                mXmlGuiClient->unplugActionList(actionlistname);
-                mXmlGuiClient->plugActionList(actionlistname, lst);
-            }
-        }
-    }
-#else
-    qCDebug(KORGANIZER_LOG) << " Plugins not implemented yet";
-#endif
-}
-
-#endif
-
-void KOrganizer::newMainWindow(const QUrl &url)
-{
-    auto korg = new KOrganizer();
-    if (url.isValid() || url.isEmpty()) {
-        korg->init(true);
-        if (mActionManager->importURL(url, false) || url.isEmpty()) {
-            korg->show();
-        } else {
-            delete korg;
-        }
-    } else {
-        korg->init(false);
-        korg->show();
-    }
-}
-
 void KOrganizer::readSettings()
 {
     // read settings from the KConfig, supplying reasonable
@@ -200,7 +172,7 @@ void KOrganizer::slotEditKeys()
 
 bool KOrganizer::queryClose()
 {
-    bool close = mActionManager->queryClose();
+    const bool close = mActionManager->queryClose();
 
     // Write configuration. I don't know if it really makes sense doing it this
     // way, when having opened multiple calendars in different CalendarViews.
